Vidyut
======

`vidyut` defines Python bindings for `Vidyut`_, a high-performance Sanskrit
toolkit. These bindings are under active development as part of the `Ambuda`_
project.


.. _Vidyut: https://github.com/ambuda-org/vidyut
.. _Ambuda: https://ambuda.org

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   chandas
   cheda
   kosha
   lipi
   prakriya
   sandhi
   api
   changes
